@@ -107,5 +107,7 @@ class MemcacheStore(BaseStore):
         cachekeys = [self.__keyvalue_helper.generate_lookup_key(klass, key) for key in keys]
         object_map = self.__client.get_multi(cachekeys)
         return [object_map.get(k, None) for k in cachekeys]
-
-            
\ No newline at end of file
+    
+    def release(self):
+        self.__client.disconnect_all()
+        
\ No newline at end of file
