@@ -159,6 +159,9 @@ class SqlAlchemyStore(BaseStore):
         else:
             return [None for k in keys]
     
+    def release(self):
+        self.__session.close()
+    
     def _sa_put(self, obj):
         try:
             self.__session.add(obj)
