@@ -170,6 +170,18 @@ class StoreFixture(object):
         self.assertEqual(obj1_r, None)
         self.assertEqual(obj2_r, None)
     
+    def test_can_close_stockpyle_and_other_methods_lazily_reopen(self):
+        
+        obj = Foobar(1,2,3)
+        self.store.put(obj)
+        self.store.release()
+        
+        obj_r = self.store.get(Foobar, {"foo": 1, "bar": 2})
+        
+        self.assertEqual(obj_r.foo, 1)
+        self.assertEqual(obj_r.bar, 2)
+        self.assertEqual(obj_r.zap, 3)
+    
 
 class ExpiringStoreFixture(object):
     
