@@ -64,3 +64,7 @@ class MockMemcacheClient(object):
     def flush_all(self):
         self.__map = {}
         self.__timeouts = {}
+    
+    def disconnect_all(self):
+        pass
+        
