@@ -3,7 +3,7 @@ try:
     __HAVE_SHOVE = True
 except ImportError:
     import sys
-    print >> sys.stderr, "\n*** warning: skipping optional Shove tests, you don't have the module (http://pypi.python.org/pypi/shove)"
+    print >> sys.stderr, "WARNING: skipping optional Shove tests, missing module 'shove' (http://pypi.python.org/pypi/shove)"
     __HAVE_SHOVE = False
 
 
