@@ -227,7 +227,15 @@ if __HAVE_SA:
             # when participating in a chain store, there are a few callbacks
             # (these are private API for now, but we need to test it)
             self.store._before_stockpyle_deserialize(obj)
-
+    
+        def test_closing_stockpyle_disallows_attribute_retrieval(self):
+        
+            obj = Foobar(1,2,3)
+            self.store.put(obj)
+            self.store.release()
+            
+            self.assertRaises(Exception, lambda: obj.foo)
+            self.assertRaises(Exception, lambda: obj.bar)
 
     class ChainedStoreWithSqlAlchemyTestCase(TestCase):
     
